@@ -509,19 +509,19 @@ class FuncOnt:
         if exists_P:
             if self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.rdftype):
                 isTypeOf=True
-            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.rdfssubclassof):
+            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.rdfsSubClassOf):
                 isSubClass = True
             elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.rdfsrange):
                 isRange=True
             elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.rdfsdomain):
                 isDomain=True
-            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlinverseof):
+            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlInverseOf):
                 isInverse=True
-            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlequivalentproperty):
+            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlEquivalentProperty):
                 isInverse=True
-            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlequivalentclass):
+            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlEquivalentClass):
                 isInverse=True
-            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlsameas):
+            elif self.CompareFullyQualifiedAndEquivalentNames(PredicateConcept,self.owlSameAs):
                 isInverse=True
         else:
             P = self.AddBaseNode(PredicateConcept)
@@ -555,7 +555,7 @@ class FuncOnt:
         O.RangeOf.append(P)
 
         if isTypeOf:
-            if O==self.GetBON(self.rdfsclass):
+            if O==self.GetBON(self.rdfsClass):
                 S.isClass=True
             else:
                 S.AddType(O)
@@ -568,9 +568,9 @@ class FuncOnt:
 
         if isSubProperty:
             S.AddSuperProperty(O)
-            if O==self.GetBON(self.owltransitive):
+            if O==self.GetBON(self.owlTransitive):
                 P.isTransitive = True
-            if O==self.identList(self.owlsymmetric):
+            if O==self.identList(self.owlSymmetric):
                 P.isSymmetric = True
 
         if isDomain:
@@ -1289,7 +1289,7 @@ class FuncOnt:
         else:
             filelist,internalOntology,_newcode = self.GetOntologyPackageFiles(pkgfolder,pkgname)
         for f in filelist:
-            print f
+            # print f
             if f[-3:].tolower() =='rdf':
                 self.ReadXML(f)
             elif f[-3:].tolower() == 'n3e':
@@ -1351,8 +1351,8 @@ class FuncOnt:
         for node in root:
             is_Description = (node.tag.lower() == self.rdfdescription.lower())
             #theSubject = self.FullyQualifiedName(node.attrib[self.rdfabout])
-            print node.attrib
-            print self.FullyQualifiedName(self.rdfabout)
+            # print node.attrib
+            # print self.FullyQualifiedName(self.rdfabout)
             theSubject = node.attrib[self.FullyQualifiedName(self.rdfabout)]
             for c in node:
                 thePredicate = c.tag #self.FullyQualifiedName(c.tag)
@@ -1371,14 +1371,14 @@ class FuncOnt:
         return
 
     def AddTripleDescription(self,theSubject,thePredicate,theObject):
-        print 'D:Adding {0} {1} {2}'.format(self.PrettyName(theSubject), self.PrettyName(thePredicate),
-                                   self.PrettyName(theObject))
+        #print 'D:Adding {0} {1} {2}'.format(self.PrettyName(theSubject), self.PrettyName(thePredicate),
+        #                           self.PrettyName(theObject))
         ont.AddTriple(self.PrettyName(theSubject), self.PrettyName(thePredicate),
                                    self.PrettyName(theObject))
         return
     def AddTripleProperty(self,theSubject,thePredicate,theObject):
-        print 'P:Adding {0} {1} {2}'.format(self.PrettyName(theSubject), self.PrettyName(thePredicate),
-                                   self.PrettyName(theObject))
+        #print 'P:Adding {0} {1} {2}'.format(self.PrettyName(theSubject), self.PrettyName(thePredicate),
+        #                           self.PrettyName(theObject))
         ont.AddTriple(self.PrettyName(theSubject), self.PrettyName(thePredicate),
                                    self.PrettyName(theObject))
         return
